<?php
/**
 * @file
 * Page callbacks for the Mandrill Inbound API module.
 */

/**
 * Page callback: Handle inbound requests.
 *
 * @param array $route_info
 *   The route information for handling request.
 */
function mandrill_inbound_api_handle_inbound($route_info) {
  if (empty($_POST['mandrill_events']) || !$mandrill_events = json_decode($_POST['mandrill_events'])) {
    watchdog('mandrill_inbound_api', 'Missing mandrill events for !url.', array('!url' => $route_info['url']));
    return variable_get('mandrill_inbound_api_testing_mode_enabled', FALSE) ? 'Mandrill Inbound API Testing Mode Enabled' : MENU_NOT_FOUND;
  }

  $testing_mode_action = variable_get('mandrill_inbound_api_testing_mode_action', 'log');
  if (variable_get('mandrill_inbound_api_testing_mode_enabled', FALSE) && $testing_mode_action != 'default') {

    if ($testing_mode_action == 'log') {
      $debug = array(
        'route_info' => $route_info,
        'mandrill_events' => $mandrill_events,
      );
      watchdog('mandrill_inbound_api_debug', '<pre>' . print_r($debug, TRUE) . '</pre>');
    }
    elseif ($testing_mode_action == 'email') {
      if ($testing_mode_email = variable_get('mandrill_inbound_api_testing_mode_email', '')) {
        foreach ($mandrill_events as $event) {
          $params['route_info'] = $route_info;
          $params['msg'] = $event->msg;
          drupal_mail('mandrill_inbound_api', 'test_mode_email', $testing_mode_email, language_default(), $params);
        }
      }
    }
  }
  else {
    if (function_exists($route_info['callback'])) {
      foreach ($mandrill_events as $delta => $event) {
        $msg = $event->msg;
        $email_identifier = mandrill_inbound_api_get_email_identifier($msg->email);
        $route_info['callback']($msg, $email_identifier);
      }
    }
  }
}
